==> jc-1.4.0.tar.gz: javax/accessibility/AccessibleRole.h <==
// public class javax.accessibility.AccessibleRole

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 31af68d307de0dce javax_accessibility_AccessibleBundle
// @dep_class 13eec6fc3dc83b49 javax_accessibility_AccessibleRole

// header file dependencies
// @dep_header javax_accessibility_AccessibleBundle

#include "javax/accessibility/AccessibleBundle.h"

#ifndef _JC_javax_accessibility_AccessibleRole_H_
#define _JC_javax_accessibility_AccessibleRole_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_accessibility_AccessibleRole$object;

// Typedefs
typedef struct _jc_javax_accessibility_AccessibleRole$sub_refs	_jc_javax_accessibility_AccessibleRole$sub_refs;
typedef struct _jc_javax_accessibility_AccessibleRole$sub_nonrefs	_jc_javax_accessibility_AccessibleRole$sub_nonrefs;
typedef struct _jc_javax_accessibility_AccessibleRole$refs	_jc_javax_accessibility_AccessibleRole$refs;
typedef struct _jc_javax_accessibility_AccessibleRole$nonrefs	_jc_javax_accessibility_AccessibleRole$nonrefs;
typedef struct _jc_javax_accessibility_AccessibleRole$object	_jc_javax_accessibility_AccessibleRole$object;

typedef struct _jc_javax_accessibility_AccessibleRole$fields_struct	_jc_javax_accessibility_AccessibleRole$fields_struct;
typedef const struct _jc_javax_accessibility_AccessibleRole$vmethods	_jc_javax_accessibility_AccessibleRole$vmethods;
typedef const struct _jc_javax_accessibility_AccessibleRole$vtable	_jc_javax_accessibility_AccessibleRole$vtable;
typedef const struct _jc_javax_accessibility_AccessibleRole$vtype	_jc_javax_accessibility_AccessibleRole$vtype;

// Class fields structure
struct _jc_javax_accessibility_AccessibleRole$fields_struct {
	struct _jc_javax_accessibility_AccessibleRole$object	*ALERT;
	struct _jc_javax_accessibility_AccessibleRole$object	*AWT__5fCOMPONENT;
	struct _jc_javax_accessibility_AccessibleRole$object	*CANVAS;
	struct _jc_javax_accessibility_AccessibleRole$object	*CHECK__5fBOX;
	struct _jc_javax_accessibility_AccessibleRole$object	*COLOR__5fCHOOSER;
	struct _jc_javax_accessibility_AccessibleRole$object	*COLUMN__5fHEADER;
	struct _jc_javax_accessibility_AccessibleRole$object	*COMBO__5fBOX;
	struct _jc_javax_accessibility_AccessibleRole$object	*DATE__5fEDITOR;
	struct _jc_javax_accessibility_AccessibleRole$object	*DESKTOP__5fICON;
	struct _jc_javax_accessibility_AccessibleRole$object	*DESKTOP__5fPANE;
	struct _jc_javax_accessibility_AccessibleRole$object	*DIALOG;
	struct _jc_javax_accessibility_AccessibleRole$object	*DIRECTORY__5fPANE;
	struct _jc_javax_accessibility_AccessibleRole$object	*FILE__5fCHOOSER;
	struct _jc_javax_accessibility_AccessibleRole$object	*FILLER;
	struct _jc_javax_accessibility_AccessibleRole$object	*FONT__5fCHOOSER;
	struct _jc_javax_accessibility_AccessibleRole$object	*FRAME;
	struct _jc_javax_accessibility_AccessibleRole$object	*GLASS__5fPANE;
	struct _jc_javax_accessibility_AccessibleRole$object	*GROUP__5fBOX;
	struct _jc_javax_accessibility_AccessibleRole$object	*HYPERLINK;
	struct _jc_javax_accessibility_AccessibleRole$object	*ICON;
	struct _jc_javax_accessibility_AccessibleRole$object	*INTERNAL__5fFRAME;
	struct _jc_javax_accessibility_AccessibleRole$object	*LABEL;
	struct _jc_javax_accessibility_AccessibleRole$object	*LAYERED__5fPANE;
	struct _jc_javax_accessibility_AccessibleRole$object	*LIST;
	struct _jc_javax_accessibility_AccessibleRole$object	*LIST__5fITEM;
	struct _jc_javax_accessibility_AccessibleRole$object	*MENU;
	struct _jc_javax_accessibility_AccessibleRole$object	*MENU__5fBAR;
	struct _jc_javax_accessibility_AccessibleRole$object	*MENU__5fITEM;
	struct _jc_javax_accessibility_AccessibleRole$object	*OPTION__5fPANE;
	struct _jc_javax_accessibility_AccessibleRole$object	*PAGE__5fTAB;
	struct _jc_javax_accessibility_AccessibleRole$object	*PAGE__5fTAB__5fLIST;
	struct _jc_javax_accessibility_AccessibleRole$object	*PANEL;
	struct _jc_javax_accessibility_AccessibleRole$object	*PASSWORD__5fTEXT;
	struct _jc_javax_accessibility_AccessibleRole$object	*POPUP__5fMENU;
	struct _jc_javax_accessibility_AccessibleRole$object	*PROGRESS__5fBAR;
	struct _jc_javax_accessibility_AccessibleRole$object	*PUSH__5fBUTTON;
	struct _jc_javax_accessibility_AccessibleRole$object	*RADIO__5fBUTTON;
	struct _jc_javax_accessibility_AccessibleRole$object	*ROOT__5fPANE;
	struct _jc_javax_accessibility_AccessibleRole$object	*ROW__5fHEADER;
	struct _jc_javax_accessibility_AccessibleRole$object	*SCROLL__5fBAR;
	struct _jc_javax_accessibility_AccessibleRole$object	*SCROLL__5fPANE;
	struct _jc_javax_accessibility_AccessibleRole$object	*SEPARATOR;
	struct _jc_javax_accessibility_AccessibleRole$object	*SLIDER;
	struct _jc_javax_accessibility_AccessibleRole$object	*SPIN__5fBOX;
	struct _jc_javax_accessibility_AccessibleRole$object	*SPLIT__5fPANE;
	struct _jc_javax_accessibility_AccessibleRole$object	*STATUS__5fBAR;
	struct _jc_javax_accessibility_AccessibleRole$object	*SWING__5fCOMPONENT;
	struct _jc_javax_accessibility_AccessibleRole$object	*TABLE;
	struct _jc_javax_accessibility_AccessibleRole$object	*TEXT;
	struct _jc_javax_accessibility_AccessibleRole$object	*TOGGLE__5fBUTTON;
	struct _jc_javax_accessibility_AccessibleRole$object	*TOOL__5fBAR;
	struct _jc_javax_accessibility_AccessibleRole$object	*TOOL__5fTIP;
	struct _jc_javax_accessibility_AccessibleRole$object	*TREE;
	struct _jc_javax_accessibility_AccessibleRole$object	*UNKNOWN;
	struct _jc_javax_accessibility_AccessibleRole$object	*VIEWPORT;
	struct _jc_javax_accessibility_AccessibleRole$object	*WINDOW;
};
extern _jc_javax_accessibility_AccessibleRole$fields_struct _jc_javax_accessibility_AccessibleRole$class_fields;

// Constructors
extern void _jc_javax_accessibility_AccessibleRole$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_accessibility_AccessibleRole$object *, struct _jc_java_lang_String$object *);

// Static methods
extern void _jc_javax_accessibility_AccessibleRole$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_javax_accessibility_AccessibleRole$vmethods {
};

// Vtable
struct _jc_javax_accessibility_AccessibleRole$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleBundle$vmethods	javax_accessibility_AccessibleBundle;
	_jc_javax_accessibility_AccessibleRole$vmethods	javax_accessibility_AccessibleRole;
};

// Vtype
struct _jc_javax_accessibility_AccessibleRole$vtype {
	_jc_type			type;
	_jc_javax_accessibility_AccessibleRole$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_accessibility_AccessibleRole$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_accessibility_AccessibleRole$refs {
    _jc_javax_accessibility_AccessibleRole$sub_refs	javax_accessibility_AccessibleRole;
    _jc_javax_accessibility_AccessibleBundle$sub_refs	javax_accessibility_AccessibleBundle;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_accessibility_AccessibleRole$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_accessibility_AccessibleRole$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleBundle$sub_nonrefs	javax_accessibility_AccessibleBundle;
    _jc_javax_accessibility_AccessibleRole$sub_nonrefs	javax_accessibility_AccessibleRole;
};

// Object instance structure
struct _jc_javax_accessibility_AccessibleRole$object {
	_jc_javax_accessibility_AccessibleRole$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_accessibility_AccessibleRole$vtype	*vtype;
	_jc_javax_accessibility_AccessibleRole$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_accessibility_AccessibleRole$vtype _jc_javax_accessibility_AccessibleRole$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_accessibility_AccessibleRole, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_accessibility_AccessibleRole$class_object;

#endif	/* _JC_javax_accessibility_AccessibleRole_H_ */

==> jc-1.4.5.tar.gz: javax/accessibility/AccessibleRole.h <==
// public class javax.accessibility.AccessibleRole

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 31af68d307de0dce javax_accessibility_AccessibleBundle
// @dep_class 13eec6fc3dc83b49 javax_accessibility_AccessibleRole

// header file dependencies
// @dep_header javax_accessibility_AccessibleBundle

#include "javax/accessibility/AccessibleBundle.h"

#ifndef _JC_javax_accessibility_AccessibleRole_H_
#define _JC_javax_accessibility_AccessibleRole_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_accessibility_AccessibleRole$object;

// Typedefs
typedef struct _jc_javax_accessibility_AccessibleRole$sub_refs	_jc_javax_accessibility_AccessibleRole$sub_refs;
typedef struct _jc_javax_accessibility_AccessibleRole$sub_nonrefs	_jc_javax_accessibility_AccessibleRole$sub_nonrefs;
typedef struct _jc_javax_accessibility_AccessibleRole$refs	_jc_javax_accessibility_AccessibleRole$refs;
typedef struct _jc_javax_accessibility_AccessibleRole$nonrefs	_jc_javax_accessibility_AccessibleRole$nonrefs;
typedef struct _jc_javax_accessibility_AccessibleRole$object	_jc_javax_accessibility_AccessibleRole$object;

typedef struct _jc_javax_accessibility_AccessibleRole$fields_struct	_jc_javax_accessibility_AccessibleRole$fields_struct;
typedef const struct _jc_javax_accessibility_AccessibleRole$vmethods	_jc_javax_accessibility_AccessibleRole$vmethods;
typedef const struct _jc_javax_accessibility_AccessibleRole$vtable	_jc_javax_accessibility_AccessibleRole$vtable;
typedef const struct _jc_javax_accessibility_AccessibleRole$vtype	_jc_javax_accessibility_AccessibleRole$vtype;

// Class fields structure
struct _jc_javax_accessibility_AccessibleRole$fields_struct {
	struct _jc_javax_accessibility_AccessibleRole$object	*ALERT;
	struct _jc_javax_accessibility_AccessibleRole$object	*AWT__5fCOMPONENT;
	struct _jc_javax_accessibility_AccessibleRole$object	*CANVAS;
	struct _jc_javax_accessibility_AccessibleRole$object	*CHECK__5fBOX;
	struct _jc_javax_accessibility_AccessibleRole$object	*COLOR__5fCHOOSER;
	struct _jc_javax_accessibility_AccessibleRole$object	*COLUMN__5fHEADER;
	struct _jc_javax_accessibility_AccessibleRole$object	*COMBO__5fBOX;
	struct _jc_javax_accessibility_AccessibleRole$object	*DATE__5fEDITOR;
	struct _jc_javax_accessibility_AccessibleRole$object	*DESKTOP__5fICON;
	struct _jc_javax_accessibility_AccessibleRole$object	*DESKTOP__5fPANE;
	struct _jc_javax_accessibility_AccessibleRole$object	*DIALOG;
	struct _jc_javax_accessibility_AccessibleRole$object	*DIRECTORY__5fPANE;
	struct _jc_javax_accessibility_AccessibleRole$object	*FILE__5fCHOOSER;
	struct _jc_javax_accessibility_AccessibleRole$object	*FILLER;
	struct _jc_javax_accessibility_AccessibleRole$object	*FONT__5fCHOOSER;
	struct _jc_javax_accessibility_AccessibleRole$object	*FRAME;
	struct _jc_javax_accessibility_AccessibleRole$object	*GLASS__5fPANE;
	struct _jc_javax_accessibility_AccessibleRole$object	*GROUP__5fBOX;
	struct _jc_javax_accessibility_AccessibleRole$object	*HYPERLINK;
	struct _jc_javax_accessibility_AccessibleRole$object	*ICON;
	struct _jc_javax_accessibility_AccessibleRole$object	*INTERNAL__5fFRAME;
	struct _jc_javax_accessibility_AccessibleRole$object	*LABEL;
	struct _jc_javax_accessibility_AccessibleRole$object	*LAYERED__5fPANE;
	struct _jc_javax_accessibility_AccessibleRole$object	*LIST;
	struct _jc_javax_accessibility_AccessibleRole$object	*LIST__5fITEM;
	struct _jc_javax_accessibility_AccessibleRole$object	*MENU;
	struct _jc_javax_accessibility_AccessibleRole$object	*MENU__5fBAR;
	struct _jc_javax_accessibility_AccessibleRole$object	*MENU__5fITEM;
	struct _jc_javax_accessibility_AccessibleRole$object	*OPTION__5fPANE;
	struct _jc_javax_accessibility_AccessibleRole$object	*PAGE__5fTAB;
	struct _jc_javax_accessibility_AccessibleRole$object	*PAGE__5fTAB__5fLIST;
	struct _jc_javax_accessibility_AccessibleRole$object	*PANEL;
	struct _jc_javax_accessibility_AccessibleRole$object	*PASSWORD__5fTEXT;
	struct _jc_javax_accessibility_AccessibleRole$object	*POPUP__5fMENU;
	struct _jc_javax_accessibility_AccessibleRole$object	*PROGRESS__5fBAR;
	struct _jc_javax_accessibility_AccessibleRole$object	*PUSH__5fBUTTON;
	struct _jc_javax_accessibility_AccessibleRole$object	*RADIO__5fBUTTON;
	struct _jc_javax_accessibility_AccessibleRole$object	*ROOT__5fPANE;
	struct _jc_javax_accessibility_AccessibleRole$object	*ROW__5fHEADER;
	struct _jc_javax_accessibility_AccessibleRole$object	*SCROLL__5fBAR;
	struct _jc_javax_accessibility_AccessibleRole$object	*SCROLL__5fPANE;
	struct _jc_javax_accessibility_AccessibleRole$object	*SEPARATOR;
	struct _jc_javax_accessibility_AccessibleRole$object	*SLIDER;
	struct _jc_javax_accessibility_AccessibleRole$object	*SPIN__5fBOX;
	struct _jc_javax_accessibility_AccessibleRole$object	*SPLIT__5fPANE;
	struct _jc_javax_accessibility_AccessibleRole$object	*STATUS__5fBAR;
	struct _jc_javax_accessibility_AccessibleRole$object	*SWING__5fCOMPONENT;
	struct _jc_javax_accessibility_AccessibleRole$object	*TABLE;
	struct _jc_javax_accessibility_AccessibleRole$object	*TEXT;
	struct _jc_javax_accessibility_AccessibleRole$object	*TOGGLE__5fBUTTON;
	struct _jc_javax_accessibility_AccessibleRole$object	*TOOL__5fBAR;
	struct _jc_javax_accessibility_AccessibleRole$object	*TOOL__5fTIP;
	struct _jc_javax_accessibility_AccessibleRole$object	*TREE;
	struct _jc_javax_accessibility_AccessibleRole$object	*UNKNOWN;
	struct _jc_javax_accessibility_AccessibleRole$object	*VIEWPORT;
	struct _jc_javax_accessibility_AccessibleRole$object	*WINDOW;
};
extern _jc_javax_accessibility_AccessibleRole$fields_struct _jc_javax_accessibility_AccessibleRole$class_fields;

// Constructors
extern void _jc_javax_accessibility_AccessibleRole$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_accessibility_AccessibleRole$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_javax_accessibility_AccessibleRole$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_accessibility_AccessibleRole$vmethods {
};

// Vtable
struct _jc_javax_accessibility_AccessibleRole$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleBundle$vmethods	javax_accessibility_AccessibleBundle;
	_jc_javax_accessibility_AccessibleRole$vmethods	javax_accessibility_AccessibleRole;
};

// Vtype
struct _jc_javax_accessibility_AccessibleRole$vtype {
	_jc_type			type;
	_jc_javax_accessibility_AccessibleRole$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_accessibility_AccessibleRole$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_accessibility_AccessibleRole$refs {
    _jc_javax_accessibility_AccessibleRole$sub_refs	javax_accessibility_AccessibleRole;
    _jc_javax_accessibility_AccessibleBundle$sub_refs	javax_accessibility_AccessibleBundle;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_accessibility_AccessibleRole$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_accessibility_AccessibleRole$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleBundle$sub_nonrefs	javax_accessibility_AccessibleBundle;
    _jc_javax_accessibility_AccessibleRole$sub_nonrefs	javax_accessibility_AccessibleRole;
};

// Object instance structure
struct _jc_javax_accessibility_AccessibleRole$object {
	_jc_javax_accessibility_AccessibleRole$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_accessibility_AccessibleRole$vtype	*vtype;
	_jc_javax_accessibility_AccessibleRole$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_accessibility_AccessibleRole$vtype _jc_javax_accessibility_AccessibleRole$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_accessibility_AccessibleRole, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_accessibility_AccessibleRole$class_object;

#endif	/* _JC_javax_accessibility_AccessibleRole_H_ */
